@@ -125,6 +125,10 @@ class MemoryFile(Generic[T], io.IOBase):
     def eof(self) -> bool:
         return self._closed or self._cursor >= len(self._data)
 
+    @property
+    def remaining_bytes(self) -> int:
+        return len(self._data) - self.tell()
+
     def writable(self) -> bool:
         if self._closed:
             return False
@@ -132,15 +136,17 @@ class MemoryFile(Generic[T], io.IOBase):
             return not self._data.readonly
         return isinstance(self._data, bytearray)
 
-    def read(self, size: int = -1) -> T:
+    def read(self, size: int = -1, peek: bool = False) -> T:
         beginning = self._cursor
         if size is None or size < 0:
-            self._cursor = len(self._data)
+            end = len(self._data)
         else:
-            self._cursor = min(self._cursor + size, len(self._data))
-        result = self._data[beginning:self._cursor]
+            end = min(self._cursor + size, len(self._data))
+        result = self._data[beginning:end]
         if self.read_as_bytes and not isinstance(result, bytes):
             result = bytes(result)
+        if not peek:
+            self._cursor = end
         return result
 
     def peek(self, size: int = -1) -> memoryview:
@@ -150,8 +156,8 @@ class MemoryFile(Generic[T], io.IOBase):
             return mv[cursor:]
         return mv[cursor:cursor + size]
 
-    def read1(self, size: int = -1) -> T:
-        return self.read(size)
+    def read1(self, size: int = -1, peek: bool = False) -> T:
+        return self.read(size, peek)
 
     def _find_linebreak(self, beginning: int, end: int) -> int:
         if not isinstance(self._data, memoryview):
@@ -339,16 +345,12 @@ class StructReader(MemoryFile[T]):
     def byteorder_name(self) -> str:
         return 'big' if self.bigendian else 'little'
 
-    @property
-    def remaining_bytes(self) -> int:
-        return len(self._data) - self.tell()
-
     def seek(self, offset, whence=io.SEEK_SET) -> int:
         self._bbits = 0
         self._nbits = 0
         return super().seek(offset, whence)
 
-    def read_exactly(self, size: Optional[int] = None) -> T:
+    def read_exactly(self, size: Optional[int] = None, peek: bool = False) -> T:
         """
         Read bytes from the underlying stream. Raises a `RuntimeError` when the stream is not currently
         byte-aligned, i.e. when `refinery.lib.structures.StructReader.byte_aligned` is `False`. Raises
@@ -359,7 +361,7 @@ class StructReader(MemoryFile[T]):
         """
         if not self.byte_aligned:
             raise StructReader.Unaligned('buffer is not byte-aligned')
-        data = self.read1(size)
+        data = self.read1(size, peek)
         if size and len(data) < size:
             raise EOF(data)
         return data
@@ -385,56 +387,63 @@ class StructReader(MemoryFile[T]):
         self.seekrel(mod and blocksize - mod)
         return nbits, bbits
 
-    def read_integer(self, length: int) -> int:
+    def read_integer(self, length: int, peek: bool = False) -> int:
         """
         Read `length` many bits from the underlying stream as an integer.
         """
         if length < self._nbits:
-            self._nbits -= length
+            new_count = self._nbits - length
             if self.bigendian:
-                result = self._bbits >> self._nbits
-                self._bbits ^= result << self._nbits
+                result = self._bbits >> new_count
+                if not peek:
+                    self._bbits ^= result << new_count
             else:
                 result = self._bbits & 2 ** length - 1
-                self._bbits >>= length
+                if not peek:
+                    self._bbits >>= length
+            if not peek:
+                self._nbits = new_count
             return result
+
         nbits, bbits = self.byte_align()
-        required = length - nbits
-        bytecount, rest = divmod(required, 8)
+        number_of_missing_bits = length - nbits
+        bytecount, rest = divmod(number_of_missing_bits, 8)
         if rest:
             bytecount += 1
             rest = 8 - rest
         if bytecount == 1:
-            result = self.read_exactly(1)[0]
+            result, = self.read_exactly(1, peek)
         else:
-            result = int.from_bytes(self.read_exactly(bytecount), self.byteorder_name)
+            result = int.from_bytes(self.read_exactly(bytecount, peek), self.byteorder_name)
         if not nbits and not rest:
             return result
         if self.bigendian:
             rbmask   = 2 ** rest - 1       # noqa
             excess   = result & rbmask     # noqa
             result >>= rest                # noqa
-            result  ^= bbits << required   # noqa
+            result  ^= bbits << number_of_missing_bits   # noqa
         else:
-            excess   = result >> required  # noqa
-            result  ^= excess << required  # noqa
+            excess   = result >> number_of_missing_bits  # noqa
+            result  ^= excess << number_of_missing_bits  # noqa
             result <<= nbits               # noqa
             result  |= bbits               # noqa
         assert excess.bit_length() <= rest
-        self._nbits = rest
-        self._bbits = excess
+        if not peek:
+            self._nbits = rest
+            self._bbits = excess
         return result
 
-    def read_bytes(self, size: int) -> bytes:
+    def read_bytes(self, size: int, peek: bool = False) -> bytes:
         """
         The method reads `size` many bytes from the underlying stream starting at the current bit.
         """
         if self.byte_aligned:
-            data = self.read_exactly(size)
+            data = self.read_exactly(size, peek)
             if not isinstance(data, bytes):
                 data = bytes(data)
             return data
-        return self.read_integer(size * 8).to_bytes(size, self.byteorder_name)
+        else:
+            return self.read_integer(size * 8, peek).to_bytes(size, self.byteorder_name)
 
     def read_bit(self) -> int:
         """
@@ -463,7 +472,7 @@ class StructReader(MemoryFile[T]):
         for bit in bits:
             yield bool(bit)
 
-    def read_struct(self, spec: str, unwrap=False) -> Union[List[UnpackType], UnpackType]:
+    def read_struct(self, spec: str, unwrap=False, peek=False) -> Union[List[UnpackType], UnpackType]:
         """
         Read structured data from the stream in any format supported by the `struct` module. The `format`
         argument can be used to override the current byte ordering. If the `unwrap` parameter is `True`, a
@@ -477,6 +486,7 @@ class StructReader(MemoryFile[T]):
         else:
             byteorder = self.byteorder_format
         data = []
+        current_cursor = self.tell()
 
         # reserved struct characters: xcbB?hHiIlLqQnNefdspP
         for k, part in enumerate(re.split('(\\d*[auwE])', spec)):
@@ -498,28 +508,33 @@ class StructReader(MemoryFile[T]):
                 data.extend(struct.unpack(part, self.read_bytes(struct.calcsize(part))))
         if unwrap and len(data) == 1:
             return data[0]
+        if peek:
+            self.seekset(current_cursor)
         return data
 
-    def read_nibble(self) -> int:
+    def read_nibble(self, peek: bool = False) -> int:
         """
         Calls `refinery.lib.structures.StructReader.read_integer` with an argument of `4`.
         """
-        return self.read_integer(4)
+        return self.read_integer(4, peek)
 
-    def u8(self) -> int: return self.read_integer(8)
-    def i8(self) -> int: return signed(self.read_integer(8), 8)
+    def u8(self, peek: bool = False) -> int: return self.read_integer(8, peek)
+    def i8(self, peek: bool = False) -> int: return signed(self.read_integer(8, peek), 8)
 
-    def u16(self) -> int: return self.read_integer(16)
-    def u32(self) -> int: return self.read_integer(32)
-    def u64(self) -> int: return self.read_integer(64)
-    def i16(self) -> int: return signed(self.read_integer(16), 16)
-    def i32(self) -> int: return signed(self.read_integer(32), 32)
-    def i64(self) -> int: return signed(self.read_integer(64), 64)
+    def u16(self, peek: bool = False) -> int: return self.read_integer(16, peek)
+    def u32(self, peek: bool = False) -> int: return self.read_integer(32, peek)
+    def u64(self, peek: bool = False) -> int: return self.read_integer(64, peek)
+    def i16(self, peek: bool = False) -> int: return signed(self.read_integer(16, peek), 16)
+    def i32(self, peek: bool = False) -> int: return signed(self.read_integer(32, peek), 32)
+    def i64(self, peek: bool = False) -> int: return signed(self.read_integer(64, peek), 64)
 
-    def read_byte(self) -> int: return self.read_integer(8)
-    def read_char(self) -> int: return signed(self.read_integer(8), 8)
+    def f32(self, peek: bool = False) -> float: return self.read_struct('f', peek=peek)
+    def f64(self, peek: bool = False) -> float: return self.read_struct('d', peek=peek)
 
-    def read_terminated_array(self, alignment: int, terminator: bytes):
+    def read_byte(self, peek: bool = False) -> int: return self.read_integer(8, peek)
+    def read_char(self, peek: bool = False) -> int: return signed(self.read_integer(8, peek), 8)
+
+    def read_terminated_array(self, alignment: int, terminator: bytes) -> bytearray:
         pos = self.tell()
         buf = self.getbuffer()
         try:
@@ -539,20 +554,37 @@ class StructReader(MemoryFile[T]):
         else:
             data = self.read_exactly(end - pos)
             self.seekrel(len(terminator))
-            return data
+            return bytearray(data)
 
-    def read_c_string(self, encoding=None) -> Union[str, bytes]:
+    def read_c_string(self, encoding=None) -> Union[str, bytearray]:
         data = self.read_terminated_array(1, B'\0')
         if encoding is not None:
             data = data.decode(encoding)
         return data
 
-    def read_w_string(self, encoding=None) -> Union[str, bytes]:
+    def read_w_string(self, encoding=None) -> Union[str, bytearray]:
         data = self.read_terminated_array(2, B'\0\0')
         if encoding is not None:
             data = data.decode(encoding)
         return data
 
+    def read_length_prefixed_ascii(self, prefix_size: int = 32):
+        return self.read_length_prefixed(prefix_size, 'latin1')
+
+    def read_length_prefixed_utf8(self, prefix_size: int = 32):
+        return self.read_length_prefixed(prefix_size, 'utf8')
+
+    def read_length_prefixed_utf16(self, prefix_size: int = 32, bytecount: bool = False):
+        block_size = 1 if bytecount else 2
+        return self.read_length_prefixed(prefix_size, 'utf-16le', block_size)
+
+    def read_length_prefixed(self, prefix_size: int = 32, encoding: Optional[str] = None, block_size: int = 1) -> Union[T, str]:
+        prefix = self.read_integer(prefix_size) * block_size
+        data = self.read(prefix)
+        if encoding is not None:
+            data = data.decode(encoding)
+        return data
+
     def read_7bit_encoded_int(self, max_bits: int = 0) -> int:
         value = 0
         for shift in itertools.count(0, step=7):
@@ -577,14 +609,12 @@ class StructMeta(type):
         original__init__ = cls.__init__
 
         @functools.wraps(original__init__)
-        def wrapped__init__(self, reader, *args, **kwargs):
+        def wrapped__init__(self: Struct, reader, *args, **kwargs):
             if not isinstance(reader, StructReader):
                 reader = StructReader(reader)
-            for key, value in kwargs.items():
-                setattr(self, key, value)
             start = reader.tell()
             view = memoryview(reader.getbuffer())
-            original__init__(self, reader, *args)
+            original__init__(self, reader, *args, **kwargs)
             self._data = view[start:reader.tell()]
 
         cls.__init__ = wrapped__init__
@@ -611,10 +641,10 @@ class Struct(metaclass=StructMeta):
     def __bytes__(self):
         return bytes(self._data)
 
-    def decouple(self):
-        if isinstance(self._data, memoryview):
+    def get_data(self, decouple=False):
+        if decouple and isinstance(self._data, memoryview):
             self._data = bytearray(self._data)
-        return self
+        return self._data
 
     def __init__(self, reader: StructReader):
         pass
