@@ -5,7 +5,12 @@ Exports two singletons `refinery.lib.types.INF` and `refinery.lib.types.AST`.
 Used by `refinery.units.pattern.PatternExtractorBase` as the default values
 for certain command line arguments.
 """
-__all__ = ['INF', 'AST']
+from typing import Union
+
+__all__ = ['INF', 'AST', 'ByteStr']
+
+
+ByteStr = Union[bytes, bytearray, memoryview]
 
 
 class INF:
