@@ -870,7 +870,7 @@ class Executable(ABCMeta):
         return cls()
 
     def __neg__(cls):
-        unit = cls()
+        unit: Unit = cls()
         unit.args.reverse = 1
         return unit
 
@@ -1199,6 +1199,7 @@ class Unit(UnitBase, abstract=True):
         return getattr(self.args, 'lenient', 0)
 
     def _exception_handler(self, exception: BaseException, data: Optional[ByteString]):
+        abort_execution = False
         if data is not None and self.leniency > 1:
             try:
                 return exception.partial
@@ -1217,8 +1218,8 @@ class Unit(UnitBase, abstract=True):
             self.log_warn(F'critical error, terminating: {exception}')
             raise exception
         elif isinstance(exception, VariableMissing):
-            self.log_warn('critical error:', exception)
-            raise RefineryCriticalException
+            self.log_warn('critical error:', exception.args[0])
+            abort_execution = True
         elif isinstance(exception, GeneratorExit):
             raise exception
         elif isinstance(exception, RefineryImportMissing):
@@ -1234,6 +1235,8 @@ class Unit(UnitBase, abstract=True):
         if self.log_debug():
             import traceback
             traceback.print_exc(file=sys.stderr)
+        if abort_execution:
+            raise RefineryCriticalException
 
     def __next__(self) -> Chunk:
         if not self._chunks:
@@ -1806,6 +1809,11 @@ class Unit(UnitBase, abstract=True):
         else:
             ps1 = None
 
+        try:
+            sys.set_int_max_str_digits(0)
+        except AttributeError:
+            pass
+
         argv = argv if argv is not None else sys.argv[1:]
         clock = None
         yappi = None
