@@ -131,16 +131,16 @@ class pemeta(Unit):
             cls._ensure_string(val)
         ) for key, val in bin.items() if val)
 
-    def parse_signature(self, data: bytearray) -> dict:
+    @classmethod
+    def parse_signature(cls, data: bytearray) -> dict:
         """
         Extracts a JSON-serializable and human readable dictionary with information about
         time stamp and code signing certificates that are attached to the input PE file.
         """
         from refinery.units.formats.pkcs7 import pkcs7
-        from refinery.units.formats.pe.pesig import pesig
 
         try:
-            signature = data | pesig | pkcs7 | json.loads
+            signature = data | pkcs7 | json.loads
         except Exception as E:
             raise ValueError(F'PKCS7 parser failed with error: {E!s}')
 
@@ -230,6 +230,7 @@ class pemeta(Unit):
         the version resource of an input PE file, if available.
         """
         pe.parse_data_directories(directories=[DIRECTORY_ENTRY['IMAGE_DIRECTORY_ENTRY_RESOURCE']])
+        string_table_entries = []
         for FileInfo in pe.FileInfo:
             for FileInfoEntry in FileInfo:
                 with suppress(AttributeError):
@@ -253,7 +254,13 @@ class pemeta(Unit):
                                 separator = ', '
                                 if re.match(F'\\d+({re.escape(separator)}\\d+){{3}}', value):
                                     StringTableEntryParsed[key] = '.'.join(value.split(separator))
-                        return StringTableEntryParsed
+                        string_table_entries.append(StringTableEntryParsed)
+        if not string_table_entries:
+            return None
+        elif len(string_table_entries) == 1:
+            return string_table_entries[0]
+        else:
+            return string_table_entries
 
     def parse_exports(self, pe: PE, data=None) -> list:
         pe.parse_data_directories(directories=[DIRECTORY_ENTRY['IMAGE_DIRECTORY_ENTRY_EXPORT']])
@@ -308,6 +315,21 @@ class pemeta(Unit):
             'MinimumOS': MinimumOS,
         }
 
+        pe.parse_data_directories(directories=[
+            DIRECTORY_ENTRY['IMAGE_DIRECTORY_ENTRY_EXPORT'],
+        ])
+
+        try:
+            export_name = pe.DIRECTORY_ENTRY_EXPORT.name
+            if isinstance(export_name, bytes):
+                export_name = export_name.decode('latin1')
+            if not re.match('[\x20!-~]+', export_name):
+                export_name = None
+        except Exception:
+            export_name = None
+        if export_name:
+            header_information['ExportName'] = export_name
+
         rich_header = pe.parse_rich_header()
         rich = []
         if rich_header:
@@ -322,7 +344,7 @@ class pemeta(Unit):
                     continue
                 pid = info.pid.upper()
                 if self.args.tabular:
-                    rich.append(F'[{idv:08x}] {count:>{cw}d} {pid:<{pw}} {info.ver}')
+                    rich.append(F'[{idv:08x}] {count:>0{cw}d} {pid:<{pw}} {info.ver}')
                 else:
                     rich.append({
                         'Counter': count,
@@ -500,7 +522,8 @@ class pemeta(Unit):
 
         if self.args.timestamps or self.args.signatures:
             with suppress(Exception):
-                signature = self.parse_signature(data)
+                from refinery.units.formats.pe.pesig import pesig
+                signature = self.parse_signature(next(data | pesig))
 
         if self.args.timestamps:
             ts = self.parse_time_stamps(pe, self.args.timeraw)
