@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+from hashlib import md5
 from refinery.units import Unit
 
 
@@ -14,7 +15,7 @@ class dedup(Unit):
             if not chunk.visible:
                 yield chunk
                 continue
-            hashed = hash(chunk)
+            hashed = md5(chunk).digest()
             if hashed not in barrier:
                 barrier.add(hashed)
                 yield chunk
