@@ -4,7 +4,7 @@ import re
 
 from fnmatch import fnmatch
 from ipaddress import ip_address
-from typing import AnyStr
+from typing import AnyStr, Union
 from urllib.parse import urlparse
 from string import ascii_letters
 from pathlib import Path
@@ -176,7 +176,7 @@ class xtp(PatternExtractor):
         B'<'[0]: B'>',
     }
 
-    def _check_match(self, data, pos, name, value):
+    def _check_match(self, data: Union[memoryview, bytearray], pos: int, name: str, value: bytes):
         term = self._BRACKETING.get(data[pos - 1], None)
         if term:
             pos = value.find(term)
@@ -198,9 +198,9 @@ class xtp(PatternExtractor):
             if self.args.filter > 2 and sum(ocets) < 10:
                 return None
             for area in (
-                data[pos - 20 : pos + 20],
-                data[pos * 2 - 40 : pos * 2 + 40 : 2],
-                data[pos * 2 - 41 : pos * 2 + 39 : 2]
+                bytes(data[pos - 20 : pos + 20]),
+                bytes(data[pos * 2 - 40 : pos * 2 + 40 : 2]),
+                bytes(data[pos * 2 - 41 : pos * 2 + 39 : 2]),
             ):
                 if B'version' in area.lower():
                     return None
@@ -330,7 +330,7 @@ class xtp(PatternExtractor):
     def process(self, data):
         whitelist = set()
 
-        def check(match):
+        def check(match: re.Match):
             for name, value in match.groupdict().items():
                 if value is not None:
                     break
@@ -338,7 +338,7 @@ class xtp(PatternExtractor):
                 raise RefineryCriticalException('Received empty match.')
             if value in whitelist:
                 return None
-            result = self._check_match(data, match.start(), name, value)
+            result = self._check_match(match.string, match.start(), name, value)
             if result is not None:
                 return self.labelled(result, pattern=name)
             whitelist.add(value)
